@@ -19,11 +19,13 @@ from ..model.gecko import GeckoModel
 from ..util.constants import ModelConstants
 from ..util.parsing import evaluate_expression_tree
 from ..util.utilities import elements
+from tqdm import tqdm
 
 LOGGER = logging.getLogger(__name__)
 
 solver_map = {'gurobi': 'gurobi', 'cplex': 'cplex', 'glpk': 'optlang'}
 
+
 # TODO: missing proteins and set objective implementations
 class CBModelContainer(ModelContainer):
     """ A basic container for REFRAMED models.
@@ -73,11 +75,11 @@ class CBModelContainer(ModelContainer):
         return self.model.get_exchange_reactions()
 
     def get_substrates(self, rxn_id):
-        reaction = self.model.reactions[rxn]
+        reaction = self.model.reactions[rxn_id]
         return {m_id: coeff for m_id, coeff in reaction.stoichiometry.items() if coeff < 0}
 
     def get_products(self, rxn_id):
-        reaction = self.model.reactions[rxn]
+        reaction = self.model.reactions[rxn_id]
         return {m_id: coeff for m_id, coeff in reaction.stoichiometry.items() if coeff > 0}
 
     @property
@@ -194,7 +196,7 @@ class Simulation(CBModelContainer, Simulator):
         wt_growth = wt_solution.objective_value
         reactions = self.model.reactions.keys()
         self._essential_reactions = []
-        for rxn in reactions:
+        for rxn in tqdm(reactions):
             res = self.simulate(constraints={rxn: 0})
             if res:
                 if (res.status == SStatus.OPTIMAL and res.objective_value < wt_growth * min_growth) \
@@ -216,7 +218,7 @@ class Simulation(CBModelContainer, Simulator):
         wt_solution = self.simulate()
         wt_growth = wt_solution.objective_value
         genes = self.model.genes
-        for gene in genes:
+        for gene in tqdm(genes):
             active_genes = set(self.model.genes) - {gene}
             active_reactions = self.evaluate_gprs(active_genes)
             inactive_reactions = set(
@@ -382,7 +384,6 @@ class Simulation(CBModelContainer, Simulator):
         formula = self.model.metabolites[metabolite_id].metadata['FORMULA']
         return elements(formula)
 
-
     # TODO: this is repeated
     def set_objective(self, reaction):
         self.model.set_objective({reaction: 1})
@@ -584,7 +585,7 @@ class GeckoSimulation(Simulation):
         wt_growth = wt_solution.objective_value
         self._essential_proteins = []
         proteins = self.model.proteins
-        for p in proteins:
+        for p in tqdm(proteins):
             rxn = "{}{}".format(self.protein_prefix, p)
             res = self.simulate(constraints={rxn: 0})
             if res:
